# YamlInfo
[![Build Status](https://travis-ci.org/AUCR/YamlInfo.svg?branch=master)](https://travis-ci.org/AUCR/YamlInfo)
[![codecov](https://codecov.io/gh/AUCR/YamlInfo/branch/master/graph/badge.svg)](https://codecov.io/gh/AUCR/YamlInfo)
[![Coverage Status](https://coveralls.io/repos/github/AUCR/YamlInfo/badge.svg)](https://coveralls.io/github/AUCR/YamlInfo)

A Project Info Yaml Configuration Module

## Organization Support Slack
[![AUCR Slack](https://slack.aucr.io/badge.svg)](https://slack.aucr.io/)

Please contact us in the organization slack and join the yamlinfo room to ask any questions!


## Overview

The AUCR yamlinfo config library is intended to make all yaml file parsing a bit more advanced. 


## Goal

The project has a simple goal to handle all the config file parsing needs we could have by giving more power to our config files.


